=========
xiRescore
=========


.. image:: https://img.shields.io/pypi/v/xirescore
        :target: https://pypi.python.org/pypi/xirescore
        :alt: PyPI - Package Version

.. image:: https://img.shields.io/pypi/pyversions/xirescore
        :target: https://pypi.python.org/pypi/xirescore
        :alt: PyPI - Python Version

.. image:: https://readthedocs.org/projects/xirescore/badge/
        :target: https://xirescore.readthedocs.io/en/
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/xirescore
        :target: https://github.com/Rappsilber-Laboratory/xiRescore/blob/main/LICENSE
        :alt: PyPI - License

.. image:: https://img.shields.io/badge/DOI-todo-gray
        :target: https://github.com/Rappsilber-Laboratory/xiRescore/
        :alt: DOI



A machine learning based approach to rescore crosslinked spectrum matches (CSMs).


* Free software: GNU Affero General Public License v3 or later (AGPLv3+)
* Documentation: https://xirescore.readthedocs.io.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
